# K_DeZero

## Overview

This library is an my improved version of "Deep Learning from Basic 3".
(In production)

## Requirement

- Python3.8
- If you use gpu, cupy
- If you want to visualize the model, install graphviz
- For details, see requirements.txt

## Usage

Method1:
```
pip install kdezero
```

Method2:
```
git clone https://github.com/kotabrog/K_DeZero.git
cd kdezero
python setup.py sdist
pip install dist\kdezero-1.7.tar.gz
```

Then you will be able to use "kdezero".

## sample

Look at [samples](https://github.com/kotabrog/K_DeZero/tree/main/samples).

## Features

This library can:

- Backpropagation-enabled variables can be used like numpy
- Contains basic machine learning parts
- Some support gpu
- Visualize model configuration using graphviz

## Author

[twitter](https://twitter.com/Kotabrog)

## Licence

[MIT](https://github.com/kotabrog/K_DeZero/blob/main/LICENSE)
